==> HostCMS-6.1.7.tar: modules/shop/purchase/discount/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS 6\Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2013 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Purchase discounts',
	'order_discount_show_title' => 'Discounts from order amount',
	'shop_order_item_discount' => 'Discount',
	'shop_order_item_discount_add' => 'Add',
	'add_order_discount_form_title' => 'Add discount from order amount',
	'edit_order_discount_form_title' => 'Edit discount from order amount',
	'name' => '<acronym title="Name of discount from total order amount">Name</acronym>',
	'active' => '<acronym title="Discount activity from total order amount">Activity</acronym>',
	'coupon' => '<acronym title="Use discount only in the presence of discount ticket">Use only with discount ticket</acronym>',
	'value' => '<acronym title="Discount amount; can be measured by per cents or a currency">Discount amount</acronym>',
	'type' => '<acronym title="Discount type - per cent or a sum in a selected currency">Discount type</acronym>',
	'start_datetime' => '<acronym title="Starting date of discount activity">Discount active from</acronym>',
	'end_datetime' => '<acronym title="End date of discount activity">Discount active to</acronym>',
	'min_amount' => '<acronym title="Initial price interval">Initial price interval</acronym>',
	'max_amount' => '<acronym title="End price interval">End price interval</acronym>',
	'shop_currency_id' => "<acronym title=\"Price currency\">Currency</acronym>",
	'order_discount_case_and' => 'AND',
	'order_discount_case_or' => 'OR',
	'order_discount_case_accumulative' => 'Accumulation discount',
	'min_count' => '<acronym title="Initial count">Initial count interval</acronym>',
	'max_count' => '<acronym title="End count">End count interval</acronym>',
	'form_edit_affiliate_values_type_percent' => 'Percentage rate',
	'form_edit_affiliate_values_type_summ' => 'Amount',
	'shop_id' => 'Shop id',
	'id' => 'Id',
	'edit_success' => 'Discount information added successfully.',
	'markDeleted_success' => "Discount information deleted successfully!",
	'changeStatus_success' => "Warehouse updated successfully",
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
);

==> HostCMS-6.8.6.tar: modules/shop/purchase/discount/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Purchase discounts',
	'order_discount_show_title' => 'Discounts from order amount',
	'shop_order_item_discount' => 'Discount',
	'shop_order_item_discount_add' => 'Add',
	'add_order_discount_form_title' => 'Add discount from order amount',
	'edit_order_discount_form_title' => 'Edit discount from order amount',
	'name' => 'Name',
	'active' => 'Active',
	'coupon' => 'Use only with discount coupon',
	'value' => '<acronym title="Discount amount; can be measured by per cents or a currency">Discount amount</acronym>',
	'type' => '<acronym title="Discount type - per cent or a sum in a selected currency">Discount type</acronym>',
	'position' => '<acronym title="Item position to calculate amount of discount">Item Position</acronym>',
	'total-amount' => 'Total Amount',
	'start_datetime' => 'Discount active from',
	'end_datetime' => 'Discount active to',
	'min_amount' => '<acronym title="Initial price interval">Initial price interval</acronym>',
	'max_amount' => '<acronym title="End price interval">End price interval</acronym>',
	'shop_currency_id' => "Currency",
	'order_discount_case_and' => 'AND',
	'order_discount_case_or' => 'OR',
	'order_discount_case_accumulative' => 'Accumulation discount',
	'min_count' => '<acronym title="Initial count">Count &gt;=</acronym>',
	'max_count' => '<acronym title="End count">Count &lt;</acronym>',
	'form_edit_affiliate_values_type_percent' => 'Percentage rate',
	'form_edit_affiliate_values_type_summ' => 'Amount',
	'shop_id' => 'Shop id',
	'id' => 'ID',
	'edit_success' => 'Discount information added successfully.',
	'markDeleted_success' => "Discount information deleted successfully!",
	'changeStatus_success' => "Warehouse updated successfully",
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
);
